summaryrefslogtreecommitdiff
path: root/sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx')
-rwxr-xr-xsd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx b/sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx
index a1a430c49328..719bc65430ea 100755
--- a/sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx
+++ b/sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx
@@ -85,7 +85,7 @@ public:
*/
virtual sal_Int32 GetMinimumWidth (void);
/** The default implementaion always returns <FALSE/>
*/
virtual bool IsResizable (void);
@@ -102,22 +102,22 @@ public:
virtual void RequestResize (void);
/** The default implementation shows the window (when it exists) when
- bExpansionState is <TRUE/>. It hides the window otherwise.
+ bExpansionState is <sal_True/>. It hides the window otherwise.
@return
- Returns <TRUE/> when the expansion state changes. When an
+ Returns <sal_True/> when the expansion state changes. When an
expansion state is requested that is already in place then
- <FALSE/> is returned.
+ <sal_False/> is returned.
*/
virtual bool Expand (bool bExpansionState);
/** The default implementation returns whether the window is showing.
- When there is no window then it returns <FALSE/>.
+ When there is no window then it returns <sal_False/>.
*/
virtual bool IsExpanded (void) const;
/** Return whether the node can be expanded or collapsed. The default
- implementation always returns <TRUE/> when there is window and
- <FALSE/> otherwise. If <FALSE/> is returned
+ implementation always returns <sal_True/> when there is window and
+ <sal_False/> otherwise. If <sal_False/> is returned
then Expand() may be called but it will not change the expansion
state.
*/
@@ -85,7 +85,7 @@ public:
*/
virtual sal_Int32 GetMinimumWidth (void);
- /** The default implementaion always returns <FALSE/>
+ /** The default implementaion always returns <sal_False/>
*/
virtual bool IsResizable (void);